# PythonPackageVersionMetadataResponseMetadata

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**dependencies** | **object** | Dependency information |
**importlib_metadata** | [**PythonPackageVersionMetadataResponseMetadataImportlibMetadata**](PythonPackageVersionMetadataResponseMetadataImportlibMetadata.md) |  |
**index_url** | **str** | Index URL from where the given package comes from |
**package_name** | **str** | Name of the Python package |
**package_version** | **str** | Version of the Python package |
**packages** | **list[str]** | Python packages (modules) the given package provides |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

